==> ae_db_ora-0.0.4.tar.gz: ae_db_ora-0.0.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# db_ora portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_db_ora/master?logo=python)](
    https://gitlab.com/ae-group/ae_db_ora)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_db_ora/coverage.svg)](
    https://ae-group.gitlab.io/ae_db_ora/coverage/ae_db_ora_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_db_ora/mypy.svg)](
    https://ae-group.gitlab.io/ae_db_ora/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_db_ora/pylint.svg)](
    https://ae-group.gitlab.io/ae_db_ora/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_db_ora)](
    https://libraries.io/pypi/ae-db-ora)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#files)


## installation


Execute the following command for to use the ae.db_ora module in your
application. It will install ae.db_ora into your python (virtual) environment:
 
```shell script
pip install ae-db-ora
```

If you instead want to contribute to this portion then first fork
[the ae_db_ora repository at GitLab](https://gitlab.com/ae-group/ae_db_ora "ae.db_ora code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_db_ora):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.db_ora.html#module-ae.db_ora
"ae_db_ora documentation").

<!-- Common files version 0.0.48 deployed  version 0.0.1 (with 0.0.48)
     to https://gitlab.com/ae-group as ae_db_ora module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project as ae-db-ora package.
-->

==> ae_db_ora-0.1.4.tar.gz: ae_db_ora-0.1.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# db_ora portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_db_ora/master?logo=python)](
    https://gitlab.com/ae-group/ae_db_ora)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_db_ora/coverage.svg)](
    https://ae-group.gitlab.io/ae_db_ora/coverage/ae_db_ora_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_db_ora/mypy.svg)](
    https://ae-group.gitlab.io/ae_db_ora/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_db_ora/pylint.svg)](
    https://ae-group.gitlab.io/ae_db_ora/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_db_ora)](
    https://libraries.io/pypi/ae-db-ora)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#files)


## installation


Execute the following command for to use the ae.db_ora module in your
application. It will install ae.db_ora into your python (virtual) environment:
 
```shell script
pip install ae-db-ora
```

If you instead want to contribute to this portion then first fork
[the ae_db_ora repository at GitLab](https://gitlab.com/ae-group/ae_db_ora "ae.db_ora code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_db_ora):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.db_ora.html#module-ae.db_ora
"ae_db_ora documentation").

<!-- Common files version 0.0.60 deployed version 0.1.4 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_db_ora module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-db-ora as namespace portion ae-db-ora.
-->
